# MOSFET Beta

We use a parameter called "beta" to describe the behavior of a MOSFET. The default value is small (20m), which is appropriate for a signal MOSFET. To simulate a power MOSFET, use a larger value like 80.

In the saturation region, Ids = beta * (Vgs - Vt)2/2.

This worksheet will calculate the value of beta for a particular MOSFET, given Rds(on).

RDS(on) (Ω) (use typical value):
VGS where measured (V):
Threshold (V) (use typical value):